@@ -47,6 +47,9 @@ class InvalidParamError(LihilError): ...
 class InvalidParamPackError(InvalidParamError): ...
 
 
+class InvalidEndpointError(LihilError): ...
+
+
 class UnserializableResponseError(LihilError):
     def __init__(self, ret: Any):
         super().__init__(f"Cannot serialize response of type: {type(ret)}")
@@ -64,3 +67,9 @@ class InvalidParamSourceError(LihilError):
     def __init__(self, source: str, param_sources: tuple[str, ...]):
         msg = f"Invalid source {source}, expected one of {param_sources}"
         super().__init__(msg)
+
+
+class RouteSetupError(LihilError):
+    def __init__(self, route: Any):
+        msg = f"Failed to setup route {route}"
+        super().__init__(msg)
