@@ -24,8 +24,8 @@ def get_swagger_ui_html(
     *,
     openapi_url: str,
     title: str,
-    swagger_js_url: str = "https://cdn.jsdelivr.net/npm/swagger-ui-dist@5.2.0/swagger-ui-bundle.js",
-    swagger_css_url: str = "https://cdn.jsdelivr.net/npm/swagger-ui-dist@5.2.0/swagger-ui.css",
+    swagger_js_url: str = "https://cdn.jsdelivr.net/npm/swagger-ui-dist@5/swagger-ui-bundle.js",
+    swagger_css_url: str = "https://cdn.jsdelivr.net/npm/swagger-ui-dist@5/swagger-ui.css",
     swagger_favicon_url: str = "",
     oauth2_redirect_url: str | None = None,
     init_oauth: dict[str, Any] | None = None,
@@ -170,9 +170,9 @@ def get_problem_ui_html(
     *,
     title: str,
     problems: list[type[DetailBase[Any]]],
-    problem_js_url: str = "https://cdn.jsdelivr.net/npm/jquery@3.6.0/dist/jquery.min.js",
-    bootstrap_css_url: str = "https://cdn.jsdelivr.net/npm/bootstrap@5.2.3/dist/css/bootstrap.min.css",
-    bootstrap_js_url: str = "https://cdn.jsdelivr.net/npm/bootstrap@5.2.3/dist/js/bootstrap.bundle.min.js",
+    problem_js_url: str = "https://cdn.jsdelivr.net/npm/jquery@3/dist/jquery.min.js",
+    bootstrap_css_url: str = "https://cdn.jsdelivr.net/npm/bootstrap@/dist/css/bootstrap.min.css",
+    bootstrap_js_url: str = "https://cdn.jsdelivr.net/npm/bootstrap@5/dist/js/bootstrap.bundle.min.js",
     problem_favicon_url: str = "",
     problem_ui_parameters: dict[str, Any] | None = None,
 ) -> Response:
