@@ -20,8 +20,10 @@ from typing import (
 )
 from warnings import warn
 
-from ididi import DependentNode, Graph, INode, Resolver
+from ididi import DependentNode, Graph, Resolver
 from ididi.config import USE_FACTORY_MARK
+from ididi.errors import UnsolvableNodeError
+from ididi.interfaces import IDependent
 from ididi.utils.param_utils import MISSING as IDIDI_MISSING
 from msgspec import Struct, convert
 from msgspec.structs import NODEFAULT, FieldInfo
@@ -82,7 +84,7 @@ def is_body_param(annt: Any) -> bool:
         if annt_origin := get_origin(annt):
             return is_body_param(annt_origin)
         if not isinstance(annt, type):
-            raise InvalidParamError(f"Invalid type {annt} for body param")
+            return False
         return is_structured_type(annt) or is_file_body(annt)
 
 
@@ -212,11 +214,12 @@ def formdecoder_factory(
 
     ptype = cast(type[T], ptype)
     form_fields = lexient_get_fields(ptype)
+    multivar_fields = set(f.name for f in form_fields if is_nontextual_sequence(f.type))
 
     def form_decoder(form_data: FormData) -> T:
         values = {}
         for ffield in form_fields:
-            if is_nontextual_sequence(ffield.type):
+            if ffield.name in multivar_fields:
                 val = form_data.getlist(ffield.encode_name)
             else:
                 val = form_data.get(ffield.encode_name)
@@ -259,6 +262,14 @@ def req_param_factory(
     else:
         decoder_ = textdecoder_factory(param_type=param_type)
 
+    param_origin, _ = get_origin_pro(param_type)
+    # Python 3.12: builtin generics expose their typing info via types.GenericAlias,
+    # which should be treated as a valid "type" for request params.
+    if not is_union_type(param_origin) and not isinstance(
+        param_origin, (type, GenericAlias)
+    ):
+        raise InvalidParamError(f"Invalid param type {param_type} for {source} param")
+
     match source:
         case "path":
             req_param = PathParam(
@@ -330,8 +341,9 @@ class EndpointParser:
         self.node_derived = set[str]()
 
     def _parse_node(
-        self, node_type: INode[..., Any], reuse: Maybe[bool] = LIHIL_MISSING
+        self, node_type: IDependent[Any], reuse: Maybe[bool] = LIHIL_MISSING
     ) -> list["ParsedParam[Any]"]:
+
         if is_present(reuse):
             node = self.graph.analyze(node_type, reuse=reuse)
         else:
@@ -339,12 +351,13 @@ class EndpointParser:
 
         params: list[Any | DependentNode] = [node]
         for dep in node.dependencies:
-            ptype, default = dep.param_type, dep.default_
-            default = LIHIL_MISSING if default is IDIDI_MISSING else default
-            sub_params = self.parse_param(dep.name, cast(type, ptype), default)
+            default = LIHIL_MISSING if dep.default_ is IDIDI_MISSING else dep.default_
+            sub_params = self.parse_param(dep.name, dep.annotation, default)
+
             for sp in sub_params:
-                if not isinstance(sp, DependentNode):
-                    self.node_derived.add(sp.name)
+                if isinstance(sp, DependentNode):
+                    continue
+                self.node_derived.add(sp.name)
             params.extend(sub_params)
         return params
 
@@ -395,7 +408,7 @@ class EndpointParser:
             # IMPORTANT: Dependency injection has higher priority than body param parsing.
             # If a type is registered in the dependency graph, treat it as a dependency
             # even if it's a structured type that could be used as a body parameter.
-            nodes = self._parse_node(param_type)
+            nodes = self._parse_node(cast(type, param_type))
             return nodes
         elif is_body_param(param_type):
             if param_meta and param_meta.decoder:
@@ -442,7 +455,6 @@ class EndpointParser:
         default: Maybe[T],
         param_meta: ParamMeta,
     ) -> "ParsedParam[T]":
-
         req_param = req_param_factory(
             name=name,
             alias=header_key,
@@ -599,7 +611,7 @@ class EndpointParser:
                 )
                 params.extend(fparams)
         else:
-            raise InvalidParamPackError(f"Invalid type for param pack {type_}")
+            raise InvalidParamPackError(f"Invalid type for param pack {name}: {type_}")
 
         return params
 
@@ -667,6 +679,8 @@ class EndpointParser:
         default: Maybe[T] = LIHIL_MISSING,
         source: ParamSource | None = None,
     ) -> list[ParsedParam[T]]:
+        # b_parsed_type, b_param_meta = self._parse_meta_from_annotation(annotation, source)
+
         parsed_type, parsed_metas = get_origin_pro(annotation)
         parsed_type = cast(type[T], parsed_type)
         param_meta: ParamMeta | None = None
@@ -688,6 +702,8 @@ class EndpointParser:
             elif param_meta.source is None:
                 param_meta = param_meta.replace(source=source)
 
+        # breakpoint()
+
         if param_meta is None or param_meta.source is None:
             res = self._parse_rule_based(
                 name=name,
@@ -718,6 +734,7 @@ class EndpointParser:
                 default = LIHIL_MISSING
             else:
                 default = param.default
+
             parsed_params = self.parse_param(name, annotation, default)
             for req_param in parsed_params:
                 if isinstance(req_param, DependentNode):
@@ -732,7 +749,7 @@ class EndpointParser:
                     params[req_param.name] = req_param
 
         if self.seen_path:
-            warn(f"Unused path keys {self.seen_path}")
+            warn(f"Unused path keys {self.seen_path} from {self.route_path}")
 
         ep_params = EndpointParams(
             params=params, bodies=bodies, nodes=nodes, plugins=plugins
@@ -745,10 +762,17 @@ class EndpointParser:
         params = self.parse_params(func_sig.parameters)
         retns = parse_returns(func_sig.return_annotation)
 
-        scoped = any(
-            self.graph.should_be_scoped(node.dependent)
-            for node in params.nodes.values()
-        )
+        scoped = False
+
+        for node in params.nodes.values():
+            try:
+                if scoped := self.graph.should_be_scoped(node.dependent):
+                    break
+            except UnsolvableNodeError as une:
+                raise InvalidParamError(
+                    f"Failed to parse dependency {node.dependent} for endpoint {self.route_path}"
+                ) from une
+
         body_param_pair = params.get_body()
         body_param = body_param_pair[1] if body_param_pair else None
 
