@@ -14,6 +14,7 @@ from typing import (
 )
 from typing import get_origin as ty_get_origin
 from typing import overload
+from functools import lru_cache
 
 from msgspec import UNSET, Struct, UnsetType
 from typing_extensions import TypeAliasType, TypeGuard, is_typeddict
@@ -82,9 +83,11 @@ def is_union_type(
     return ty_get_origin(t) in (Union, UnionType)
 
 
-def is_nontextual_sequence(
-    type_: Any, strict: bool = False
-) -> TypeGuard[list[Any] | tuple[Any] | bytearray]:
+NON_TEXTUAL_SEQUENCE_TYPES = (list, tuple, bytearray, set, frozenset)
+
+
+@lru_cache
+def is_nontextual_sequence(type_: Any, strict: bool = True) -> TypeGuard[Sequence[Any]]:
     type_origin = ty_get_origin(type_) or type_
 
     if type_origin is Union:
@@ -93,13 +96,10 @@ def is_nontextual_sequence(
     if not isinstance(type_origin, type):
         return False
 
-    if type_origin in (str, bytes):
-        return False
-
-    if issubclass(type_origin, Sequence):
+    if issubclass(type_origin, NON_TEXTUAL_SEQUENCE_TYPES):
         return True
-
-    return not strict and issubclass(type_origin, (set, frozenset))
+    else:
+        return not strict and issubclass(type_origin, Sequence)
 
 
 def is_text_type(t: type | UnionType | GenericAlias) -> bool:
